#!/usr/bin/env python3

import getpass
import importlib.util
import os
import os.path
import pyclip
import time
import subprocess
import sys

def main():
    config = Config()

    file = _latest("/home/gnarwhal/Pictures/Screenshots")
    print(f"=> Selected file '{file}'")

    id = time.time_ns()
    (_, extension) = os.path.splitext(file)
    target_file_name = f"{id}{extension}"
    target_destination = f"{config.ssh_user}@{config.ssh_target}:{config.ssh_dir}/{target_file_name}"
    print(f"=> Uploading to '{target_destination}'")
    process = subprocess.run([
        "scp",
        f"-P {config.ssh_port}",
        file,
        target_destination,
    ])
    if process.returncode != 0:
        print("=> Error: failed to upload file")
        sys.exit(1)

    target_url = f"https://{config.ssh_target}/sshare/{target_file_name}"
    pyclip.copy(target_url)
    print(f"=> File available at '{target_url}'")

    sys.exit(0)


def _latest(directory, key=os.path.getmtime):
    files         = map(lambda file: f"{directory}/{file}", os.listdir(directory))
    selection     = next(files)
    selection_key = key(selection)
    for file in files:
        new_key = key(file)
        if new_key > selection_key:
            selection     = file
            selection_key = key
    return selection
    

class Config:
    def __init__(self):
        self.ssh_port   = 2222
        self.ssh_user   = getpass.getuser()
        self.ssh_target = "monodon.me"
        self.ssh_dir    = "/srv/sshare"
